Index: trunk/psphot/src/psphotReadoutFindPSF.c
===================================================================
--- trunk/psphot/src/psphotReadoutFindPSF.c	(revision 21249)
+++ trunk/psphot/src/psphotReadoutFindPSF.c	(revision 21366)
@@ -18,6 +18,6 @@
     PS_ASSERT_PTR_NON_NULL (readout, false);
 
-    // Generate the mask and weight images, including the user-defined analysis region of interest
-    psphotSetMaskAndWeight (config, readout, recipe);
+    // Generate the mask and variance images, including the user-defined analysis region of interest
+    psphotSetMaskAndVariance (config, readout, recipe);
 
     // display the image, weight, mask (ch 1,2,3)
